#!/usr/bin/perl -w
#
use strict;
#
####################################################################
#
# Name: getRates.pl - a script to compute hourly detection rates based
#       on a detection file for a station
#
# Copyright (C) 2012  Product Team, IRIS Data Management Center 
#
#    This is a free software; you can redistribute it and/or modify
#    it under the terms of the GNU Lesser General Public License as
#    published by the Free Software Foundation; either version 3 of the
#    License, or (at your option) any later version.
#    
#    This software is distributed in the hope that it will be useful, but
#    WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License (GNU-LGPL) for more details.  The
#    GNU-LGPL and further information can be found here:
#    http://www.gnu.org/
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Description:
#
#    Script reads a detection file for a single station and creates an hourly 
#    detection rate output file. The script is currently designed to accept full PSD detections.
#    To accept other detection formats, simply modify the input statement.
#
# Input:
#
#       1. from http://www.iris.edu/dms/products/infrasound/detector/repository/
#         download the weekly detection file (full power spectra detections) of interest
#
#       2. Use the "grep" command on the detection file to extract only detections for a single
#          station.
#
#          grep 959A TA_EP_BDF_PSD-all-detection.txt > IRIS_TAID_TA_959A_2012-36.txt
#
#   
# Example:
#
#     getRates.pl <detection file name> <rate file name>
#
#     getRates.pl IRIS_TAID_TA_959A_2012-36.txt IRIS_TAID_TA_959A_2012-36_rate.txt
#    
# History:
#
#    2012-11-05 (MB): created
#
#
#
# 

###############################################################################
# trim blanks
################################################################################
sub Trim
   {
   my $line = $_[0];
   chomp($line);
   $line =~ s/^\s+//;
   $line =~ s/\s+$//;
   return $line;
   }

###############################################################################
# MAIN
################################################################################

#
# get user parameters
#
my $stationFileName = "./stationList.txt";

unless ($#ARGV != 2)
   {
   print STDERR "[ERR] expected detection and rate file names\n";
   exit;
   }
my $detectionFileName = $ARGV[0];
$detectionFileName    = Trim($detectionFileName);
my $rateFileName      = $ARGV[1];
$rateFileName         = Trim($rateFileName);

#
# read and parse detection file
#
open DETECTIONFILE , "<  $detectionFileName";
my $count = 0;
my %rate = ();
while (<DETECTIONFILE>)
   {
   $count++;
   $_ = Trim($_);
   my ($sta,$start,$back,$peak,$t) = split('\|',$_);
   $sta     = Trim($sta);
   $start   = Trim($start);
   my $date = (split(":",$start))[0];
   chomp $date;
   if($rate{$date}){$rate{$date}++;}else{$rate{$date}=1;}
   }

close DETECTIONFILE;

#
# output rates
#
open RATEFILE , ">  $rateFileName";
for(sort keys %rate)
   {
   print RATEFILE $_."   ".$rate{$_}."\n";
   }

close RATEFILE;

